/*
 * Copyright (c) 2020-2026 Valve Corporation
 * Copyright (c) 2020-2026 LunarG, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Authors:
 * - Christophe Riccio <christophe@lunarg.com>
 */

#pragma once

enum ConfiguratorMode {
    CONFIGURATOR_MODE_NONE = 0,
    CONFIGURATOR_MODE_GUI,
    CONFIGURATOR_MODE_CMD,
    CONFIGURATOR_MODE_DRY,

    CONFIGURATOR_MODE_FIRST = CONFIGURATOR_MODE_NONE,
    CONFIGURATOR_MODE_LAST = CONFIGURATOR_MODE_DRY,
};

enum { CONFIGURATOR_MODE_COUNT = CONFIGURATOR_MODE_LAST - CONFIGURATOR_MODE_FIRST + 1 };

inline bool RequireLoading(ConfiguratorMode mode) { return mode == CONFIGURATOR_MODE_GUI || mode == CONFIGURATOR_MODE_CMD; }
